Package: Hmisc
Version: 5.2-2
Date: 2025-01-10
Title: Harrell Miscellaneous
Authors@R: 
    c(person(given = "Frank E",
           family = "Harrell Jr",
           role = c("aut", "cre"),
           email = "fh@fharrell.com",
           comment = c(ORCID = "0000-0002-8271-5493")),
			person(given = "Charles",
			       family = "Dupont",
						 role = "ctb",
						 email = "charles.dupont@vumc.org",
						 comment = "contributed several functions and maintains latex functions"))
Maintainer: Frank E Harrell Jr <fh@fharrell.com>
Depends: R (>= 4.2.0)
Imports: methods, ggplot2, cluster, rpart, nnet, foreign, gtable, grid,
        gridExtra, data.table, htmlTable (>= 1.11.0), viridis,
        htmltools, base64enc, colorspace, rmarkdown, knitr, Formula
Suggests: survival, qreport, acepack, chron, rms, mice, rstudioapi,
        tables, plotly (>= 4.5.6), rlang, plyr, VGAM, leaps, pcaPP,
        digest, parallel, polspline, abind, kableExtra, rio, lattice,
        latticeExtra, gt, sparkline, jsonlite, htmlwidgets, qs,
        getPass, keyring, safer, htm2txt
Description: Contains many functions useful for data
	analysis, high-level graphics, utility operations, functions for
	computing sample size and power, simulation, importing and annotating datasets,
	imputing missing values, advanced table making, variable clustering,
	character string manipulation, conversion of R objects to LaTeX and html code,
	recoding variables, caching, simplified parallel computing, encrypting and decrypting data using a safe workflow, general moving window statistical estimation, and assistance in interpreting principal component analysis.
License: GPL (>= 2)
LazyLoad: Yes
URL: https://hbiostat.org/R/Hmisc/
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2025-01-10 13:14:35 UTC; harrelfe
Author: Frank E Harrell Jr [aut, cre] (<https://orcid.org/0000-0002-8271-5493>),
  Charles Dupont [ctb] (contributed several functions and maintains latex
    functions)
Repository: CRAN
Date/Publication: 2025-01-10 23:30:03 UTC
Built: R 4.4.2; x86_64--netbsd; 2025-12-18 22:29:36 UTC; unix
