exportPattern("^([^.]|\\..+\\.)")
useDynLib(Hmisc, .registration=TRUE, .fixes="F_")

import(methods)
import(stats)
import(survival)
import(Formula)
# import(grid)
import(lattice)
import(ggplot2)
## import(scales)

importFrom(acepack, ace, avas)
importFrom(base64enc, base64encode)
importFrom(latticeExtra, useOuterStrips, resizePanels)
importFrom(cluster, clara)
importFrom(foreign, read.dta, lookup.xport, read.spss, read.xport)
importFrom(gtable, gtable_add_grob)
importFrom(nnet, multinom)
importFrom(rpart, rpart, rpart.control)
importFrom(grid, convertX, convertY, grid.segments, gpar, convertUnit, grid.polygon, is.unit, grid.rect, grid.xaxis, grid.yaxis, convertWidth, convertHeight, grid.text, viewport, grobWidth, grobHeight)
importFrom(gridExtra, arrangeGrob)
importFrom(htmlTable, htmlTable, txtRound)
importFrom(htmltools, HTML)

## importFrom(tables, tabular, table_options)
## importFrom(ggplot2, geom_segment)

importFrom(grDevices, adjustcolor, col2rgb, dev.list, gray, rainbow,
           xy.coords, png, dev.off)
importFrom(graphics, abline, arrows, axis, axis.Date,
           axis.POSIXct, barplot, box, hist, legend, lines,
           locator, mtext, par, plot, plot.new,
           plot.window, points, polygon, rect, segments,
           strheight, strwidth, symbols, text, title)
importFrom(utils, browseURL, capture.output, download.file, find,
           getFromNamespace, object.size, read.csv, read.table)
           
importFrom(data.table, is.data.table, key)

S3method(print, arrGrob)
S3method(ggplot, transcan)
S3method(ggplot, summaryP)
S3method(print, spower)
S3method(print, Quantile2)
S3method(plot, describe)
S3method(plot, Quantile2)
S3method(plot, summaryP)
S3method(plot, summaryS)
S3method(plot, transcan)
S3method(label, default)
S3method(label, data.frame)
S3method('label<-', default)
S3method('label<-', data.frame)
S3method('[', labelled)
S3method('[', ffdflabel)
S3method(print, labelled)
S3method(relevel, labelled)
S3method(label, Surv)
S3method(units, default)
S3method(units, Surv)

S3method(Ecdf,data.frame)
S3method(Ecdf,default)
S3method(Ecdf,formula)
S3method(Function,areg.boot)

S3method(Function,transcan)
S3method(Label,data.frame)
S3method(Math,mChoice)
S3method(Mean,areg.boot)

S3method(Ops,mChoice)
S3method(Quantile,areg.boot)
S3method(Summary,mChoice)
S3method(as.character,mChoice)

S3method(as.data.frame,ffdflabel)
S3method(as.data.frame,impute)
S3method(as.data.frame,labelled)
S3method(as.data.frame,roundN)

S3method(as.data.frame,special.miss)
S3method(as.data.frame,substi)
S3method(as.discrete,default)

S3method(as.double,Cbind)
S3method(as.double,mChoice)
S3method(as.numeric,Cbind)
S3method(ceil,POSIXt)

S3method(ceil,default)
S3method(consolidate,default)
S3method(contents,data.frame)
S3method(contents,list)

S3method(datadensity,data.frame)
S3method(describe,data.frame)
S3method(describe,default)

S3method(describe,formula)
S3method(describe,matrix)
S3method(describe,vector)
S3method(dvi,latex)
S3method(dvigv,dvi)

S3method(dvigv,latex)
S3method(dvips,dvi)
S3method(dvips,latex)
S3method(format,mChoice)

S3method(format,special.miss)
S3method(format,timePOSIXt)
S3method(formula,summary.formula.cross)

S3method(hist,data.frame)
S3method(html,contents.data.frame)
S3method(html,data.frame)
S3method(html,default)
S3method(html,describe)
S3method(html,describe.single)
S3method(html,summaryM)

S3method(html,latex)
S3method(impute,default)
S3method(impute,transcan)
S3method('is.na<-',discrete)

S3method(jitter2,data.frame)
S3method(jitter2,default)
S3method(latex,bystats)
S3method(latex,bystats2)

S3method(latex,default)
S3method(latex,describe)
S3method(latex,describe.single)
S3method(latex,'function')

S3method(latex,list)
S3method(latex,responseSummary)
S3method(latex,summary.formula.cross)

S3method(latex,summary.formula.response)
S3method(latex,summary.formula.reverse)

S3method(latex,summaryM)
S3method(latex,summaryP)
S3method('length<-',discrete)
S3method(napredict,delete)

S3method(naprint,delete)
S3method(naprint,keep)
S3method(naresid,delete)
S3method(naresid,keep)
S3method(plot,areg)

S3method(plot,areg.boot)
S3method(plot,aregImpute)
S3method(plot,biVar)
S3method(plot,curveRep)
S3method(plot,drawPlot)

S3method(plot,gbayes)
S3method(plot,rm.boot)
S3method(plot,summary.formula.response)

S3method(plot,summary.formula.reverse)
S3method(plot,summaryM)
S3method(plot,varclus)

S3method(predict,areg)
S3method(predict,areg.boot)
S3method(predict,dataRep)
S3method(predict,transcan)

S3method(print,abs.error.pred)
S3method(print,areg)
S3method(print,areg.boot)
S3method(print,aregImpute)

S3method(print,biVar)
S3method(print,bystats)
S3method(print,bystats2)
S3method(print,char.list)

S3method(print,char.matrix)
S3method(print,contents.data.frame)
S3method(print,contents.list)

S3method(print,curveRep)
S3method(print,dataRep)
S3method(print,describe)
S3method(print,describe.single)

S3method(print,dvi)
S3method(print,find.matches)
S3method(print,hoeffd)
# S3method(print,html)

S3method(print,improveProb)
S3method(print,impute)
S3method(print,latex)
S3method(print,lrcum)
S3method(print,mChoice)

S3method(print,mhgr)
S3method(print,popower)
S3method(print,posamsize)
S3method(print,predict.dataRep)

S3method(print,rcorr)
S3method(print,redun)
S3method(print,responseSummary)
S3method(print,special.miss)

S3method(print,substi)
S3method(print,summary.areg.boot)
S3method(print,summary.formula.cross)

S3method(print,summary.formula.response)
S3method(print,summary.formula.reverse)

S3method(print,summary.mChoice)
S3method(print,summaryM)
S3method(print,t.test.cluster)

S3method(print,timePOSIXt)
S3method(print,transcan)
S3method(print,varclus)
S3method(rcorrcens,formula)

S3method(round,POSIXt)
S3method(spearman2,default)
S3method(spearman2,formula)
S3method(summary,areg.boot)

S3method(summary,find.matches)
S3method(summary,formula)
S3method(summary,impute)
S3method(summary,mChoice)

S3method(summary,transcan)
S3method(trunc,POSIXt)
S3method('units<-',default)
S3method(vcov,default)

S3method(vcov,fit.mult.impute)
S3method(xtfrm,labelled)
